# Copyright 2015-2016 Yelp Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import mock
from mock import patch

from paasta_tools.cli.cmds import docker_exec


@patch('paasta_tools.cli.cmds.docker_exec.get_subparser', autospec=True)
def test_add_subparser(mock_get_subparser):
    mock_subparsers = mock.Mock()
    docker_exec.add_subparser(mock_subparsers)
    assert mock_get_subparser.called
    mock_get_subparser.return_value.add_argument.assert_called_with('exec_command',
                                                                    help='Command to append to docker docker_exec',
                                                                    nargs='?',
                                                                    default='/bin/bash')


@patch('paasta_tools.cli.cmds.docker_exec.subprocess', autospec=True)
@patch('paasta_tools.cli.cmds.docker_exec.get_container_name', autospec=True)
@patch('paasta_tools.cli.cmds.docker_exec.pick_slave_from_status', autospec=True)
@patch('paasta_tools.cli.cmds.docker_exec.get_status_for_instance', autospec=True)
def test_paasta_docker_exec(mock_get_status_for_instance, mock_pick_slave_from_status, mock_get_container_name,
                            mock_subprocess):
    mock_status = mock.Mock(marathon=mock.Mock(app_id='appID1'))
    mock_get_status_for_instance.return_value = mock_status
    mock_args = mock.Mock(cluster='cluster1',
                          service='mock_service',
                          instance='mock_instance',
                          host='host1',
                          mesos_id=None,
                          exec_command='/bin/bash')
    mock_pick_slave_from_status.return_value = 'host1'

    docker_exec.paasta_docker_exec(mock_args)
    mock_get_status_for_instance.assert_called_with(cluster='cluster1',
                                                    service='mock_service',
                                                    instance='mock_instance')
    mock_pick_slave_from_status.assert_called_with(status=mock_status,
                                                   host='host1')

    mock_get_container_name.assert_called_with('appID1', slave_hostname='host1', task_id=None)
    expected = ["ssh", "-o", "LogLevel=QUIET", "-tA", mock_pick_slave_from_status.return_value,
                "sudo docker exec -ti {0} ''/bin/bash''".format(mock_get_container_name.return_value)]
    mock_subprocess.call.assert_called_with(expected)
